version 12.1

*     ***************************************************************** *;
*     ***************************************************************** *;
*       Source:         Code inspired by Brambor et al. 2006, Understan-*;
*						ding Interaction Models, in Political Analysis  *;
*       File-Name:      int.do		                                    *;
*       Date:           July 23, 2016                                   *;
*       Author:         Lisa Maria Dellmuth                             *;
*       Purpose:        Do-file to replicate Figure 2 in paper "The     *;
*                       Knowledge Gap in World Politics, RIS 2016       *;
*       Input File:     know.dta		                                *;
*       Data Output:    sim.dta	                                        *; 
*       Machine:        Macbook Pro                                     *;
*     ****************************************************************  *;
*     ****************************************************************  *;




*     ****************************************************************  *;
*       Restore model 10 in Table 1.                                    *;
*     ****************************************************************  *;

estimates restore model10
        
		
*     ****************************************************************  *;
*       Take 10,000 draws from the estimated coefficient vector and     *;
*       variance-covariance matrix.                                     *;
*     ****************************************************************  *;

#delimit ;

preserve;

set seed 339487731;

drawnorm MG_b1-MG_b15, n(10000) means(e(b)) cov(e(V)) clear;

*     ****************************************************************  *;
*       To calculate the desired quantities of interest we need to set  *;
*       up a loop. First, specify what you quantities should be saved   *;
*		and what these quantities should be called.                     *;
*     ****************************************************************  *;

postutil clear;

cd "/Users/mariadellmuth/Desktop/";

postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi 
            using sim.dta, replace;
            
noisily display "start";
            
			
*     ****************************************************************  *;
*       Start loop. Let `a' be the modifying variable income inequality *;
*       and let this run from min to max in the desired increments.     *;
*     ****************************************************************  *; 

local a=23 ;
while `a' <= 46 { ;

{;
scalar h_inc       = 1       ; /*This is the median of income. So, I estimate the 
effect of a one-unit unit increase in income from its median on the probability 
of knowledge for the case when`a'=0.*/
scalar h_solt_ginet= 34.01449 ; // Mean of income inequality.
scalar h_Control1  = 1        ; // Median (cosmopolitan identity).
scalar h_Control2  = 41.97239 ; // Mean age.
scalar h_Control3  = 0        ; // M (males). 
scalar h_Control4  = 1        ; // Median (secondary education).
scalar h_Control5  = 0        ; // Median (postsecondary education).
scalar h_Control6  = 7.860447 ; // Mean district size.
scalar h_Control7  = .5394317 ; // Median for party system.
scalar h_Control8  = 2        ; // Median for parliamentarism.
scalar h_Control9  = 1.5      ; // Median for unitarism.
scalar h_constant  = 0        ; // Keep random effects at 0.
							
    generate x_betahat0 = MG_b1*h_inc
                            + MG_b2*`a' 
							+ MG_b3*h_inc*`a'
                            + MG_b4*h_Control1
                            + MG_b5*h_Control2
                            + MG_b6*h_Control3
                            + MG_b7*h_Control4
                            + MG_b8*h_Control5
                            + MG_b9*h_Control6
                            + MG_b10*h_Control7
                            + MG_b11*h_Control8
                            + MG_b12*h_Control9 
                            + MG_b13*h_constant;
    
    generate x_betahat1 = MG_b1*(h_inc+1)
                            + MG_b2*`a'
                            + MG_b3*(h_inc+1)*`a' // Counterfactual scenario where income increases by 1 quintile.
                            + MG_b4*h_Control1
                            + MG_b5*h_Control2
                            + MG_b6*h_Control3
                            + MG_b7*h_Control4
                            + MG_b8*h_Control5
                            + MG_b9*h_Control6
                            + MG_b10*h_Control7
                            + MG_b11*h_Control8
                            + MG_b12*h_Control9  
                            + MG_b13*h_constant;
                            
gen prob0=normal(MG_b15-x_betahat0)-normal(MG_b14-x_betahat0); // Yields P(y=1|x). See Jeffrey M. Wooldridge, Econometric Analysis of Cross Section and Panel Data (Cambridge, MA: MIT Press, 2001), p. 505, equation 15.88.
gen prob1=normal(MG_b15-x_betahat1)-normal(MG_b14-x_betahat1); 
gen diff=prob1-prob0;    
    
    egen probhat0 =mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);    
           
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi;  

    _pctile prob0, p(2.5,97.5) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(2.5,97.5);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(2.5,97.5);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  
   
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi');
   
    };      
    
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat;
    
    local a=`a'+ 1;
    
    display "." _c;
    
} ;

display "";

postclose mypost;


*     ****************************************************************  *;                                  
*       Call on posted quantities of interest.                          *;
*     ****************************************************************  *;

restore;

merge using sim.dta;

gen yline=0;

gen MV = _n+20;

replace  MV=. if _n>50;

#delimit cr


*     ****************************************************************  *;                                  
*       Plot Figure 2.						                            *;
*     ****************************************************************  *;

preserve

drop if _n>25

sum MV

#delimit ;
graph twoway line diff_hat MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||  line yline MV,  clwidth(thin) clcolor(black) clpattern(solid)
        ||  line diff_lo MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  line diff_hi MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel(, nogrid labsize(2)) 
            ylabel(, axis(1) nogrid labsize(2)) 
            yscale(noline)  xscale(noline) legend(off)
            yline(0, lcolor(black)) 
            xtitle(Income inequality, size(2.5))
            ytitle("Marginal effect of income quintile", size(2.5))
            xsca(titlegap(4)) ysca(titlegap(4)) 
            scheme(s2mono) graphregion(fcolor(white) ilcolor(white) lcolor(white));
#delimit cr

drop prob_hat0-MV
